Twabulous
=========

Twitter + Fabulous = Twabulous

Watch the twitter streaming sample api in fabulous color in your console!

Install
=======

::
        $ pip install twabulous

Usage
=====
::
        $ twabulous
